@@ -433,6 +433,12 @@ class BacklogClient(Client):
         out = result['records'][0]['Total'] or 0
         return int(out)
     
+    def get_average_age_of_work_items(self, work_ids):
+        soql = "Select avg(Age__c) age from ADM_Work__c where ID in('{}')".format("','".join(work_ids))
+        result = self.sf_session.query(soql)
+        out = result['records'][0]['age'] or 0
+        return int(out)
+    
     def get_work_status_history(self, workid):
         result = self.sf_session.query("SELECT CreatedDate, OldValue, NewValue FROM ADM_Work__History where parentId = '{}' and Field = 'Status__c'".format(workid))
         out = []
